#!/bin/sh

# Name of the app
APP_NAME="PulseChain Dashboard.app"

# Check if the app exists in the current directory
if [ -d "$APP_NAME" ]; then
    # Check if the file has the quarantine attribute
    if xattr -p com.apple.quarantine "$APP_NAME" >/dev/null 2>&1; then
        # If quarantine attribute exists, remove it
        echo "Removing quarantine attribute from $APP_NAME..."
        xattr -d com.apple.quarantine "$APP_NAME"
       
        if [ $? -eq 0 ]; then
            echo "Successfully removed quarantine attribute."
        else
            echo "Failed to remove quarantine attribute. Make sure you have permission to execute this script."
            exit 1  # Exit if xattr fails
        fi
    else
        echo "No quarantine attribute found on $APP_NAME. Proceeding..."
    fi
   
    # Attempt to open the app
    echo "Opening $APP_NAME..."
    open "$APP_NAME"
   
    if [ $? -eq 0 ]; then
        echo "Successfully opened $APP_NAME."
    else
        echo "Failed to open $APP_NAME. Please check system logs for more details."
        exit 1  # Exit if app fails to launch
    fi
   
else
    echo "$APP_NAME not found in the current directory."
    echo "Please place this script in the same directory as $APP_NAME and try again."
    exit 1  # Exit if app is not found
fi
